/*
Copyright (C) 2007-2009 Ramon Ziai
Copyright (C) 2007-2009 Niels Ott

Licensed under the Apache License, Version 2.0 (the "License"); you may not use 
this file except in compliance with the License. You may obtain a copy of the 
License at 
     http://www.apache.org/licenses/LICENSE-2.0 
Unless required by applicable law or agreed to in writing, software distributed 
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR 
CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
language governing permissions and limitations under the License.
 */


package de.linuxusers.levenshtein.simple;

import de.linuxusers.levenshtein.algos.LevenshteinDistance;
import de.linuxusers.levenshtein.util.Conversion;

/**
 * Simple-to-use convenience class for computing the Levensthein Distance
 * of two strings.
 * Insertion, deletion and replacement produce the cost 1 in this
 * simple frontend.
 * 
 * @version $Id: Levenshtein.java 42 2010-05-17 12:46:34Z niels $
 * @author Ramon Ziai
 * @author Niels Ott
 * @deprecated Use the static method {@link de.linuxusers.levenshtein.util.SimpleLevenshtein#getStringDistance(String, String)} instead.
 */
public class Levenshtein {
	
	LevenshteinDistance<Character> levDistance;

	/**
	 * Creates and initializes a new Levenshtein Distance class for 
	 * computing the distance of strings.
	 */
	public Levenshtein()  {
		
		levDistance = new LevenshteinDistance<Character>();
		
	}

	/**
	 * Computes the Levenshtein Distance of two strings.
	 * @param s1 the first string.
	 * @param s2 the second string.
	 * @return the Levenshtein Distance yielded by comparing the two strings given.
	 */
	public float getStringDistance(String s1, String s2) {
		
		return levDistance.getDistance(
				Conversion.convertToArray(s1), 
				Conversion.convertToArray(s2));
		
	}
	

}
