package de.linuxusers.levenshtein.util;

import de.linuxusers.levenshtein.algos.LevenshteinDistance;

/**
 * Class providing a static convenience method for computing the minimum edit distance (Levensthein distance) of
 * two strings.
 * @author nott
 * @version $Id: SimpleLevenshtein.java 42 2010-05-17 12:46:34Z niels $
 */
public class SimpleLevenshtein {

	/**
	 * Computes the minimum edit distance (aka Levensthein distance) of two strings.
	 * This uses the {@link de.linuxusers.levenshtein.editweight.EqualsWeightCalculator} for obtaining the costs for insert, delete, and replace
	 * operations.
	 * @param s1 the first string.
	 * @param s2  the second string.
	 * @return The edit distance of the two strings.
	 */
	public static float getStringDistance(String s1, String s2) {

		return (new LevenshteinDistance<Character>()).getDistance(
				Conversion.convertToArray(s1), 
				Conversion.convertToArray(s2));

	}



}
